==> kdebase-3.4.2.tar.bz2: kdebase-3.4.2/kcontrol/kfontinst/viewpart/FontViewPartFactory.h <==
#ifndef __FONT_VIEW_PART_FACTORY_H__
#define __FONT_VIEW_PART_FACTORY_H__

////////////////////////////////////////////////////////////////////////////////
//
// Class Name    : KFI::CFontViewPartFactory
// Author        : Craig Drummond
// Project       : K Font Installer
// Creation Date : 03/08/2002
// Version       : $Revision: 363303 $ $Date: 2004-11-16 03:08:35 +0100 (Di, 16 Nov 2004) $
//
////////////////////////////////////////////////////////////////////////////////
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
////////////////////////////////////////////////////////////////////////////////
// (C) Craig Drummond, 2002, 2003, 2004
////////////////////////////////////////////////////////////////////////////////

#include <klibloader.h>

class KInstance;
class KAboutData;

namespace KFI
{

class CFontViewPartFactory : public KLibFactory
{
    Q_OBJECT

    public:

    CFontViewPartFactory();
    virtual ~CFontViewPartFactory();
    virtual QObject *createObject(QObject *parent = 0, const char *name = 0, const char *classname = "QObject", const QStringList &args = QStringList());

    static KInstance * instance();

    private:

    static KInstance  *theirInstance;
    static KAboutData *theirAbout;
};

}

#endif

==> kdebase-3.5.7.tar.bz2: kdebase-3.5.7/kcontrol/kfontinst/viewpart/FontViewPartFactory.h <==
#ifndef __FONT_VIEW_PART_FACTORY_H__
#define __FONT_VIEW_PART_FACTORY_H__

////////////////////////////////////////////////////////////////////////////////
//
// Class Name    : KFI::CFontViewPartFactory
// Author        : Craig Drummond
// Project       : K Font Installer
// Creation Date : 03/08/2002
// Version       : $Revision: 465343 $ $Date: 2005-09-29 15:24:25 +0200 (Do, 29 Sep 2005) $
//
////////////////////////////////////////////////////////////////////////////////
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//
////////////////////////////////////////////////////////////////////////////////
// (C) Craig Drummond, 2002, 2003, 2004
////////////////////////////////////////////////////////////////////////////////

#include <klibloader.h>

class KInstance;
class KAboutData;

namespace KFI
{

class CFontViewPartFactory : public KLibFactory
{
    Q_OBJECT

    public:

    CFontViewPartFactory();
    virtual ~CFontViewPartFactory();
    virtual QObject *createObject(QObject *parent = 0, const char *name = 0, const char *classname = "QObject", const QStringList &args = QStringList());

    static KInstance * instance();

    private:

    static KInstance  *theirInstance;
    static KAboutData *theirAbout;
};

}

#endif
